FontSize

Enum FontSize 

pub enum FontSize {
    Pixel(Pixel),
    Em(Em),
}
The size of font. Pixels is an absolute length unit and relative to the view device, and Emis relative length unit relative toPixel`. We stipulate FontSize::Em(1.) equal to FontSize::Pixel(16.)

Variants



Pixel(Pixel)



Em(Em)

Implementations

Source

impl FontSize

pub fn into_pixel(self) -> Pixel

pub fn into_em(self) -> Em

pub fn relative_em(self, em: f32) -> Em

Em scale by font size.