Path

Struct Path 

pub struct Path { /* private fields */ }
Path widget describe a shape, build the shape from [Builder]!

Implementations

Source

impl Path

pub fn builder() -> PathBuilder

pub fn bounds(&self) -> &Rect<f32, LogicUnit>

pub fn rect(rect: &Rect<f32, LogicUnit>) -> Path

create a rect path.

pub fn rect_round(rect: &Rect<f32, LogicUnit>, radius: &Radius) -> Path

Creates a path for a rectangle by rect with radius. #[inline]

pub fn circle(center: Point2D<f32, LogicUnit>, radius: f32) -> Path

create a circle path.

pub fn stroke( &self, options: &StrokeOptions, ts: Option<&Transform2D<f32, LogicUnit, LogicUnit>>, ) -> Option<Path>

Convert this path to a stroked path

ts is the current transform of the path pre applied. Provide it have a more precise convert.

pub fn transform(self, ts: &Transform2D<f32, LogicUnit, LogicUnit>) -> Path

Returns a transformed path in place.

Some points may become NaN/inf therefore this method can fail.

pub fn sampler(&self) -> PathSampler

Create an sampler that can queries point at this path or usb-path of this path.

pub fn segments(&self) -> impl Iterator<Item = PathSegment>