InheritTheme

Struct InheritTheme 

pub struct InheritTheme {
    pub palette: Option<Rc<Palette>>,
    pub typography_theme: Option<TypographyTheme>,
    pub icon_size: Option<IconSize>,
    pub icons: Option<HashMap<NamedSvg, Resource<Svg>, RandomState>>,
    pub transitions_theme: Option<TransitionTheme>,
    pub compose_decorators: Option<ComposeDecorators>,
    pub custom_styles: Option<CustomStyles>,
    pub font_bytes: Option<Vec<Vec<u8>>>,
    pub font_files: Option<Vec<String>>,
}
Inherit theme override part of parent theme, if anything not found in here, should query in parent theme until meet a FullTheme.

Fields

palette: Option<Rc<Palette>>typography_theme: Option<TypographyTheme>icon_size: Option<IconSize>

icon size standard

icons: Option<HashMap<NamedSvg, Resource<Svg>, RandomState>>

a collection of icons.

transitions_theme: Option<TransitionTheme>compose_decorators: Option<ComposeDecorators>custom_styles: Option<CustomStyles>font_bytes: Option<Vec<Vec<u8>>>font_files: Option<Vec<String>>