pub struct Opacity {
pub opacity: f32,
}Fields
opacity: f32Trait Implementations
Sourceimpl Query for Opacity
impl Query for Opacity
Sourceimpl Render for Opacity
impl Render for Opacity
Sourcefn perform_layout(&self, clamp: BoxClamp, ctx: &mut LayoutCtx<'_>) -> Size
fn perform_layout(&self, clamp: BoxClamp, ctx: &mut LayoutCtx<'_>) -> Size
Do the work of computing the layout for this widget, and return the
size it need. Read more
Sourcefn paint(&self, ctx: &mut PaintingCtx<'_>)
fn paint(&self, ctx: &mut PaintingCtx<'_>)
paint is a low level trait to help you draw your widget to paint device
across PaintingCtx::painter by itself coordinate system. Not care
about children’s paint in this method, framework will call children’s
paint individual. And framework guarantee always paint parent before
children.Sourcefn only_sized_by_parent(&self) -> bool
fn only_sized_by_parent(&self) -> bool
Whether the constraints from parent are the only input to detect the
widget size, and child nodes’ size not affect its size.
Sourcefn hit_test(&self, _: &HitTestCtx, _: Point) -> HitTest
fn hit_test(&self, _: &HitTestCtx, _: Point) -> HitTest
Determines the set of render widgets located at the given position.
fn get_transform(&self) -> Option<Transform>
impl SingleChild for Opacity