BoxPipe

Struct BoxPipe 

pub struct BoxPipe<V>(/* private fields */);
A trait object type for Pipe, help to store a concrete Pipe or just a value.

This type not implement Pipe trait to avoid boxing the Pipe twice and has a better conversion from Pipe to BoxPipe.

Call into_pipe to convert it to a Pipe type.

Implementations

Source

impl<V: 'static> BoxPipe<V>

pub fn value(v: V) -> Self

pub fn pipe(p: Box<dyn Pipe<Value = V>>) -> Self

pub fn into_pipe(self) -> Box<dyn Pipe<Value = V>>