ComposeBuilder

Trait ComposeBuilder 

pub trait ComposeBuilder {
    // Required method
    fn build(self, ctx: &BuildCtx<'_>) -> Widget;
}
Trait to build a compose widget into widget tree with BuildCtx in the build phase. You should not implement this trait directly, implement Compose trait instead.

Required Methods

fn build(self, ctx: &BuildCtx<'_>) -> Widget