pub enum FontSize {
Pixel(Pixel),
Em(Em),
}Expand description
The size of font. Pixels is an absolute length unit and relative to the view device, and Emis relative length unit relative toPixel`. We
stipulate FontSize::Em(1.) equal to FontSize::Pixel(16.)
Variants
Implementations