pub struct Path { /* private fields */ }Expand description
Path widget describe a shape, build the shape from [Builder]!
Implementations
Sourceimpl Path
impl Path
pub fn builder() -> PathBuilder
pub fn bounds(&self) -> &Rect<f32, LogicUnit>
Sourcepub fn rect_round(rect: &Rect<f32, LogicUnit>, radius: &Radius) -> Path
pub fn rect_round(rect: &Rect<f32, LogicUnit>, radius: &Radius) -> Path
Creates a path for a rectangle by rect with radius.
#[inline]
Sourcepub fn stroke(
&self,
options: &StrokeOptions,
ts: Option<&Transform2D<f32, LogicUnit, LogicUnit>>,
) -> Option<Path>
pub fn stroke( &self, options: &StrokeOptions, ts: Option<&Transform2D<f32, LogicUnit, LogicUnit>>, ) -> Option<Path>
Convert this path to a stroked path
ts is the current transform of the path pre applied. Provide it have a
more precise convert.
Sourcepub fn transform(self, ts: &Transform2D<f32, LogicUnit, LogicUnit>) -> Path
pub fn transform(self, ts: &Transform2D<f32, LogicUnit, LogicUnit>) -> Path
Returns a transformed path in place.
Some points may become NaN/inf therefore this method can fail.
Sourcepub fn sampler(&self) -> PathSampler
pub fn sampler(&self) -> PathSampler
Create an sampler that can queries point at this path or usb-path of this path.
pub fn segments(&self) -> impl Iterator<Item = PathSegment>