pub struct BoxDecoration {
pub background: Option<Brush>,
pub border: Option<Border>,
pub border_radius: Option<Radius>,
}Expand description
The BoxDecoration provides a variety of ways to draw a box.
Fields
background: Option<Brush>The background of the box.
border: Option<Border>A border to draw above the background
border_radius: Option<Radius>The corners of this box are rounded by this BorderRadius. The round
corner only work if the two borders beside it are same style.