pub struct BoxPipe<V>(/* private fields */);Expand description
A trait object type for Pipe, help to store a concrete Pipe
or just a value.
This type not implement Pipe trait to avoid boxing the Pipe twice and
has a better conversion from Pipe to BoxPipe.
Call into_pipe to convert it to a Pipe type.
Implementations